# -*- coding: utf-8 -*-

__version__ = r'4.1.0'

hagworm_label = f'Hagworm/{__version__}'

hagworm_slogan = r'''
 __  __   ______   ______   __     __   ______   ______   __    __
/\ \_\ \ /\  __ \ /\  ___\ /\ \  _ \ \ /\  __ \ /\  == \ /\ "-./  \
\ \  __ \\ \  __ \\ \ \__ \\ \ \/ ".\ \\ \ \/\ \\ \  __< \ \ \-./\ \
 \ \_\ \_\\ \_\ \_\\ \_____\\ \__/".~\_\\ \_____\\ \_\ \_\\ \_\ \ \_\
  \/_/\/_/ \/_/\/_/ \/_____/ \/_/   \/_/ \/_____/ \/_/ /_/ \/_/  \/_/
'''
